function createTimer(step) {
  if (step === void 0) {
    step = 1 / 120;
  }

  var frameId;
  var last = -1;
  var acc = 0;
  var tick = 0;
  var onUpdate = new Set();
  var onRender = new Set();

  function onFrame(time) {
    if (last >= 0) {
      acc = acc + (time - last) / 1000;

      while (acc > step) {
        onUpdate.forEach(function (update) {
          update(step, ++tick);
        });
        acc = acc - step;
      }
    }

    last = time;
    onRender.forEach(function (render) {
      render();
    });
    frameId = requestAnimationFrame(onFrame);
  }

  function start() {
    if (frameId) {
      return;
    }

    last = -1;
    frameId = requestAnimationFrame(onFrame);
  }

  function stop() {
    cancelAnimationFrame(frameId);
    frameId = NaN;
  }

  return {
    start: start,
    stop: stop,
    onUpdate: onUpdate,
    onRender: onRender
  };
}

export { createTimer };
//# sourceMappingURL=index.modern.js.map
